@@ -18,13 +18,14 @@ from testflows._core.test import TestStep, TestCase, TestSuite, TestModule, Test
 from testflows._core.test import Context, SharedContext
 from testflows._core.test import Feature, Background, Scenario, Example, Outline
 from testflows._core.test import Critical, Major, Minor, Check, Given, When, Then, And, But, By, Finally, Cleanup
-from testflows._core.test import TestFeature, TestScenario, TestCheck, loads, ordered, retry, retries, repeat, repeats
+from testflows._core.test import TestFeature, TestScenario, TestCheck
+from testflows._core.test import loads, ordered, retry, retries, repeat, repeats, define
 from testflows._core.has import has
 from testflows._core.flags import Flags
 from testflows._core.objects import OK, XOK, Fail, XFail, Skip, Error, XError, Null, XNull
 from testflows._core.objects import Name, Description, Uid, Tags, Args, Setup, Parallel, Executor
 from testflows._core.objects import XFails, XFlags, Repeats, Repeat, Retries, Retry, Onlys, Skips
-from testflows._core.objects import OnlyTags, SkipTags
+from testflows._core.objects import OnlyTags, SkipTags, Maps
 from testflows._core.objects import FFails, Skipped, Failed, XFailed, XErrored, Okayed, XOkayed
 from testflows._core.objects import Attributes, Requirements, Specifications, Examples, ArgumentParser
 from testflows._core.objects import Node, Tag, Argument, Attribute, Requirement, Specification, Metric, Value, Ticket
